@@ -2,7 +2,7 @@
 
 test_that("annotate has the correct class", {
 
-  class(annotate()) %in% c("fabric", "htmlwidget") |>
+  class(annotate()) %in% c("annotator_fabric", "htmlwidget") |>
   all() |>
   expect_true()
 
@@ -10,7 +10,7 @@ test_that("annotate has the correct class", {
 
 test_that("annotate accepts an image", {
   im = system.file("sample_images", "aves", "1.jpg", package = "annotator")
-  class(annotate(im)) %in% c("fabric", "htmlwidget") |>
+  class(annotate(im)) %in% c("annotator_fabric", "htmlwidget") |>
   all() |>
   expect_true()
 
